healthgraph-api
===============

Python Client Library for Health Graph API (http://developer.runkeeper.com/healthgraph). 
The API can be used for accessing RunKeeper.com (http://runkeeper.com) for retrieving, 
updating, deleting and uploading Fitness Activity and Health Measurements Information.

The Health Graph API uses OAuth 2.0 for security. Every application must be registered 
with the Applications Portal of  Health Graph (http://runkeeper.com/partner). 
Once registered, the application will be assigned a unique client identifier and 
client secret for use with the Health Graph API.